==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Sistemi po kthehet prapa, ju lutemi, prisni…</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Kthimi prapa dështoi.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riniseni</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Përditësimet dështuan.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Përditësimet dështuan: procesi u ndërpre.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Përditësimet dështuan: gabim DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Përditësimet dështuan: hapësirë disku e pamjaftueshme.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Jeni i sigurt se doni të kthehet prapa te %1, kopjeruajtur më %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Anuloje dhe Rinisu</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Ripohojeni</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.24.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_sq.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Sistemi po kthehet prapa, ju lutemi, prisni…</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Kthimi prapa dështoi.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riniseni</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Përditësimet dështuan.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Përditësimet dështuan: procesi u ndërpre.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Përditësimet dështuan: gabim DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Përditësimet dështuan: hapësirë disku e pamjaftueshme.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Jeni i sigurt se doni të kthehet prapa te %1, kopjeruajtur më %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Anuloje dhe Rinisu</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Ripohojeni</translation>
    </message>
</context>
</TS>
